==> flutter_kz_library-0.0.1.tar.gz: lib/src/helpers/ProgressDialogHelper.dart <==
import 'package:flutter/material.dart';
import 'package:progress_dialog/progress_dialog.dart';

class ProgressDialogHelper {
  ProgressDialog initDialogLoading(
      {String message, BuildContext context, ProgressDialogType type, bool isDismissible}) {

    var pr = new ProgressDialog(context,
        type: type, isDismissible: isDismissible, showLogs: false);

    pr.style(
        message: message,
        borderRadius: 10.0,
        backgroundColor: Colors.white,
        progressWidget: CircularProgressIndicator(),
        elevation: 10.0,
        insetAnimCurve: Curves.easeInOut,
        progress: 0.0,
        maxProgress: 100.0,
        progressTextStyle: TextStyle(
            color: Colors.black, fontSize: 13.0, fontWeight: FontWeight.w400),
        messageTextStyle: TextStyle(
            color: Colors.black, fontSize: 19.0, fontWeight: FontWeight.w600)
    );

    return pr;
  }

  ProgressDialog initDialogProgress(
      {String message, BuildContext context, ProgressDialogType type, bool isDismissible, double progress = 0.0, double maxProgress = 0.0}) {

    var pr = new ProgressDialog(context,
        type: type, isDismissible: isDismissible, showLogs: false);

    pr.style(
        message: message,
        borderRadius: 10.0,
        backgroundColor: Colors.white,
        progressWidget: CircularProgressIndicator(),
        elevation: 10.0,
        insetAnimCurve: Curves.easeInOut,
        progress: progress,
        maxProgress: maxProgress,
        progressTextStyle: TextStyle(
            color: Colors.black, fontSize: 13.0, fontWeight: FontWeight.w400),
        messageTextStyle: TextStyle(
            color: Colors.black, fontSize: 19.0, fontWeight: FontWeight.w600)
    );

    return pr;
  }
}

==> flutter_kz_library-0.0.8.tar.gz: lib/src/helpers/ProgressDialogHelper.dart <==
import 'package:flutter/material.dart';
import 'package:progress_dialog/progress_dialog.dart';

class ProgressDialogHelper {
  ProgressDialog initDialogLoading(
      {String message,
      BuildContext context,
      ProgressDialogType type,
      bool isDismissible}) {
    var pr = new ProgressDialog(context,
        type: type, isDismissible: isDismissible, showLogs: false);

    pr.style(
        message: message,
        borderRadius: 10.0,
        backgroundColor: Colors.white,
        progressWidget: CircularProgressIndicator(),
        elevation: 10.0,
        insetAnimCurve: Curves.easeInOut,
        progress: 0.0,
        maxProgress: 100.0,
        progressTextStyle: TextStyle(
            color: Colors.black, fontSize: 13.0, fontWeight: FontWeight.w400),
        messageTextStyle: TextStyle(
            color: Colors.black, fontSize: 19.0, fontWeight: FontWeight.w600));

    return pr;
  }

  ProgressDialog initDialogProgress(
      {String message,
      BuildContext context,
      ProgressDialogType type,
      bool isDismissible,
      double progress = 0.0,
      double maxProgress = 0.0}) {
    var pr = new ProgressDialog(context,
        type: type, isDismissible: isDismissible, showLogs: false);

    pr.style(
        message: message,
        borderRadius: 10.0,
        backgroundColor: Colors.white,
        progressWidget: CircularProgressIndicator(),
        elevation: 10.0,
        insetAnimCurve: Curves.easeInOut,
        progress: progress,
        maxProgress: maxProgress,
        progressTextStyle: TextStyle(
            color: Colors.black, fontSize: 13.0, fontWeight: FontWeight.w400),
        messageTextStyle: TextStyle(
            color: Colors.black, fontSize: 19.0, fontWeight: FontWeight.w600));

    return pr;
  }
}
